{% extends 'base.html' %}

{% block title -%}
    Search &mdash; {{ super() }}
{%- endblock %}

{% block breadcrumbs %}
  {% if DISPLAY_BREADCRUMBS %}
    <ol class="breadcrumb">
        <li><a href="{{ SITE_ROOT_URL | default('/') }}" title="{{ SITENAME }}"><span class="fa fa-home fa-lg"></span></a></li>
      {% if MENUITEMS_2_AT %}
        <li><a href="{{ SITEURL -}} / {{- MENUITEMS_2_AT_LINK }}" title="{{ MENUITEMS_2_AT }}">{{ MENUITEMS_2_AT }}</a></li>
      {% endif %}
        <li class="active"><a href="{{ SITEURL -}} / {{- SEARCH_URL | default('search.html') }}" title="Search">Search</a></li>
    </ol>
  {% endif %}
{% endblock %}

{% block scripts %}
    {% if 'assets' in PLUGINS %}
        {% include 'includes/minify_tipuesearch.html' with context %}
    {% else %}
        <script type="text/javascript" src="{{ SITEURL -}} / {{- THEME_STATIC_DIR }}/tipuesearch/tipuesearch_set.js"></script>
        <script type="text/javascript" src="{{ SITEURL -}} / {{- THEME_STATIC_DIR }}/tipuesearch/tipuesearch.min.js"></script>
    {% endif %}
    <script type="text/javascript" src="{{ SITEURL }}/tipuesearch_content.js"></script>
    <script type="text/javascript">
        $(document).ready(function() {
            $('#tipue_search_input').tipuesearch({
                //'mode' : 'json',
                'show': 10,
                'newWindow': false,
                //'contentLocation': 'tipuesearch_content.json'
            });
        });
    </script>
{% endblock %}

{% block content %}
<div id="tipue_search_content"></div>
{% endblock %}
