{% if article.related_posts %}
<section class="well" id="related-posts">
    <h4>{{ RELATED_POSTS_TEXT | default('Related Posts:') }}</h4>
    <ul>
    {% for related_post in article.related_posts %}
        <li><a href="{{ SITEURL -}} / {{- related_post.url }}">{{ related_post.title }}</a></li>
    {% endfor %}
    </ul>
</section>
{% endif %}
