{% assets filters="jspacker", output="js/all-js.js", "js/jquery.min.js", "js/bootstrap.min.js", "js/respond.min.js" %}
<script type="text/javascript" src="{{ SITEURL -}} / {{- ASSET_URL }}"></script>
{% endassets %}
